package server.command.commands;

import java.util.Collection;
import java.util.List;

import common.entity.npc.EntityNPC;
import common.init.ItemRegistry;
import common.item.ItemStack;
import common.tags.TagObject;
import server.command.Command;
import server.command.CommandEnvironment;
import server.command.Executor;
import server.command.RunException;
import server.command.StringCompleter;
import server.command.UserPolicy;

public class CommandItem extends Command {
	public CommandItem() {
		super("item");

		this.addString("item", false, new StringCompleter() {
			public Collection<String> complete(CommandEnvironment env) {
				return ItemRegistry.REGISTRY.getKeys();
			}
		});
		this.setParamsOptional();
		this.addInt("amount", 1, ItemStack.MAX_SIZE, 1);
		this.addTag("tag", 't');
		this.setParamsRequired();
		this.addPlayerEntityList("players", 'p', true, UserPolicy.NON_ADMINS_OR_SELF);
	}
	
	public Object exec(CommandEnvironment env, Executor exec, String item, int amount, TagObject tag, List<EntityNPC> players) {
		ItemStack stack = ItemRegistry.getFromIdName(item, null);
		if(stack == null)
			throw new RunException("Gegenstand '%s' existiert nicht", item);
		stack.setTagCompound(tag);
		int done = 0;
		int given = 0;
		for(EntityNPC player : players) {
			int total = amount;
			while(total > 0) {
				int added = Math.min(total, stack.getMaxStackSize());
				ItemStack st = stack.copy();
				st.size = added;
				player.inventory.addItemStackToInventory(st);
				added -= st.size;
				if(added <= 0)
					break;
				total -= added;
			}
			total = amount - total;
			if(total <= 0)
				continue;
			exec.log("%d * %s zum Inventar von %s hinzugefügt", total, stack.getDisplayName(), player.getCommandName());
			done++;
			given += total;
		}
		if(done > 1)
			exec.log("%d * %s an %d Spieler verteilt", given, stack.getDisplayName(), done);
		return given;
	}
}
