package server.command.commands;

import java.util.List;

import common.collect.Lists;
import common.entity.types.EntityLiving;
import common.potion.Potion;
import server.command.Command;
import server.command.CommandEnvironment;
import server.command.Executor;
import server.command.UserPolicy;

public class CommandMilk extends Command {
	public CommandMilk() {
		super("milk");
		
		this.addLivingEntityList("entities", true, UserPolicy.NON_ADMINS_OR_SELF);
		this.setParamsOptional();
		List<Potion> potions = Lists.newArrayList();
		for(Potion potion : Potion.values()) {
			if(!potion.isInstant())
				potions.add(potion);
		}
		this.addEnum("type", Potion.class, potions);
		
		this.addFlag("negative", 'n');
	}
	
	public Object exec(CommandEnvironment env, Executor exec, List<EntityLiving> entities, Potion type, boolean negative) {
		int done = 0;
		for(EntityLiving entity : entities) {
			if(type != null && entity.hasEffect(type)) {
				int amplifier = entity.getEffect(type).getAmplifier();
				entity.removeEffect(type);
				exec.log("%s von %s entfernt", type.getDisplay(amplifier), entity.getCommandName());
				done++;
			}
			else if(type == null && !entity.getEffects().isEmpty()) {
				entity.clearEffects(negative);
				exec.log("Alle Effekte von %s entfernt", entity.getCommandName());
				done++;
			}
		}
		if(done > 1)
			exec.log(type == null ? "Alle Effekte von %d Objekten entfernt" : "%d Effekte entfernt", entities.size());
		return done;
	}
}
